@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2011-2019 Rumma & Ko Ltd
+# Copyright 2011-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 
@@ -54,6 +54,7 @@ from lino.core.workflows import State, Workflow, ChangeStateAction
 from lino.core.fields import fields_list, ImportedFields
 from lino.core.fields import Dummy, DummyField
 from lino.core.fields import TimeField
+from lino.core.fields import TableRow
 
 # 20140314 need a Dummy object to define a dummy module
 # from lino.core.layouts import BaseLayout as Dummy  # 20140314
@@ -165,6 +166,8 @@ strftime = settings.SITE.strftime
 demo_date = settings.SITE.demo_date
 is_abstract_model = settings.SITE.is_abstract_model
 is_installed = settings.SITE.is_installed
+resolve_plugin = settings.SITE.resolve_plugin
+get_plugin_setting = settings.SITE.get_plugin_setting
 # get_db_overview_rst = settings.SITE.get_db_overview_rst
 add_welcome_handler = settings.SITE.add_welcome_handler
 build_media_url = settings.SITE.build_media_url
@@ -174,18 +177,10 @@ get_default_language = settings.SITE.get_default_language
 get_language_info = settings.SITE.get_language_info
 resolve_languages = settings.SITE.resolve_languages
 babelattr = settings.SITE.babelattr
-
-# apps = plugins = settings.SITE.plugins
 plugins = settings.SITE.plugins
-# `apps` is a deprecated alias for `plugins`. We recommend plugins
-# since `apps` is being used by Django 1.7
-
 format_currency = settings.SITE.format_currency
 
 
-def resolve_plugin(app_label):
-    return plugins.get(app_label, None)
-
 from django.utils import translation
 get_language = translation.get_language
 
