@@ -21,7 +21,7 @@ from bs4 import BeautifulSoup
 from rstgen import table
 import rstgen
 from rstgen import attrtable
-from atelier.utils import unindent, rmu, sixprint
+from rstgen.utils import unindent, rmu, sixprint
 
 from lino.utils import AttrDict
 from lino.utils import i2d
