@@ -296,18 +296,18 @@ class Action(Parametrizable, Permittable):
     of the plugin.
 
     Also can be defined as a class method, that takes the actor as the only
-    argument and should return a JavaScript runnable wrapped inside a function.
+    argument and should return a JavaScript executable.
     An example use case is defined in
     :class:`lino.modlib.help.models.OpenHelpWindow` where the return string
     follows the format::
 
-        return "() => window.open('URL')"
+        return "let _ = window.open('URL')"
 
     Callable Example::
 
         def js_handler(self, actor):
             ...
-            return JS_RUNABLE_INSIDE_A_WRAPPER_FUNCTION
+            return JS_EXECUTABLE
 
     """
 
@@ -1219,8 +1219,9 @@ class WrappedAction(Action):
 
     def __init__(self, bound_action, **kwargs):
         self.bound_action = bound_action
-        kwargs.update(action_name=(str(bound_action.actor).replace('.', '_') +
-            '_' + bound_action.action.action_name))
+        if 'action_name' not in kwargs and self.action_name is None:
+            kwargs.update(action_name=(str(bound_action.actor).replace('.', '_') +
+                '_' + bound_action.action.action_name))
         for k in self.WRAPPED_ATTRS:
             if k not in kwargs:
                 kwargs[k] = getattr(bound_action.action, k)
