@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2021 Rumma & Ko Ltd
+# Copyright 2009-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """This defines :class:`Actor` and related classes.
@@ -113,8 +113,9 @@ def field_getter(name):
         return getattr(obj, name)
     return func
 
+from lino.core.classproperty import classproperty
 
-class ActorMetaClass(type):
+class ActorMetaClass(type('classproperty', (classproperty,), {})):
 
     def __new__(meta, classname, bases, classDict):
         #~ if not classDict.has_key('app_label'):
@@ -147,7 +148,7 @@ class ActorMetaClass(type):
         if declared_editable is not None:
             classDict.update(_editable=declared_editable)
 
-        cls = type.__new__(meta, classname, bases, classDict)
+        cls = super().__new__(meta, classname, bases, classDict)
 
         #~ if not classDict.has_key('label'):
             #~ cls.label = ClassProperty(cls.get_actor_label)
@@ -729,6 +730,10 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
             raise ChangedAPI(
                 "{0} must convert `required` to `required_roles`".format(cls))
 
+        if hasattr(cls, 'display_mode'):
+            raise ChangedAPI(
+                "{0} must convert `display_mode` to `display_mode_main` or `display_mode_slave`".format(cls))
+
         master = getattr(cls, 'master', None)
         if isinstance(master, str):
         # if isinstance(master, string_types):
@@ -1074,7 +1079,8 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
                             if k not in required_states:
                                 st2da[k].add(ba.action.action_name)
 
-    def collect_extra_actions():
+    @classmethod
+    def collect_extra_actions(cls):
         return []
 
     @classmethod
@@ -1725,7 +1731,7 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
     @classmethod
     def slave_as_html(cls, master, ar):
         """
-        Creates and returns the method to be used when :attr:`display_mode`
+        Creates and returns the method to be used when :attr:`display_mode_main`
         is `html`.
         """
         ar = cls.request(
@@ -1744,7 +1750,7 @@ class Actor(with_metaclass(ActorMetaClass, type('NewBase', (actions.Parametrizab
     def get_table_summary(cls, obj, ar):
         """Return the HTML `<div>` to be displayed by
         :class:`lino.core.elems.TableSummaryPanel`.  That is (1) in a
-        detail form when :attr:`display_mode` is `summary` or (2)
+        detail form when :attr:`display_mode_main` is `summary` or (2)
         in a grid.
 
         Lino internally creates a virtualfield ``slave_summary`` on each table
