@@ -1,4 +1,4 @@
-# Copyright 2009-2020 Rumma & Ko Ltd
+# Copyright 2009-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 """Defines explicit code names for URL parameters
 
@@ -53,11 +53,14 @@ WINDOW_TYPE_GALLERIA = "g"
 WINDOW_TYPE_INSERT = "i"
 WINDOW_TYPE_PARAMS = "p"
 
+URL_PARAM_DISPLAY_MODE = "dm"
+
 DISPLAY_MODE_TABLE = "grid"
 DISPLAY_MODE_DETAIL = "detail"
 DISPLAY_MODE_CARDS = "cards"
 DISPLAY_MODE_LIST = "list"
 DISPLAY_MODE_GALLERY = "gallery"
+DISPLAY_MODE_STORY = 'story'
 DISPLAY_MODE_SUMMARY = "summary"
 DISPLAY_MODE_HTML = "html"
 
