@@ -1,4 +1,4 @@
-# Copyright 2009-2021 Rumma & Ko Ltd
+# Copyright 2009-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
@@ -26,7 +26,7 @@ from lino.core import actions
 from lino.core.model import Model
 from lino.core import actors
 from lino.core import constants
-from lino.core.requests import ActionRequest
+from lino.core.tablerequest import TableRequest
 
 from lino.core.choicelists import ChoiceListField
 from .utils import models_by_base
@@ -607,6 +607,8 @@ class Table(AbstractTable):
         applies request parameters.
         """
         # print("20181121b get_request_queryset", self)
+        if not isinstance(ar, TableRequest):
+            ar = self.request(parent=ar)
 
         def apply(qs):
 
