@@ -34,6 +34,10 @@ from lino.utils import quantities
 from lino.utils import choosers
 from lino.utils.quantities import Duration
 
+from .signals import pre_ui_save
+
+def none_getter(obj, ar=None):
+    return None
 
 def validate_incomplete_date(value):
     """Raise ValidationError if user enters e.g. a date 30.02.2009.
@@ -234,6 +238,7 @@ class FakeField(object):
     remote_field = None
     blank = True  # 20200425
     delayed_value = False
+    max_length = 0
 
     wildcard_data_elem = False
     """Whether to consider this field as wildcard data element.
@@ -1229,6 +1234,8 @@ class TableRow(object):
         # print("20210213 save_existing_instance", ar.ah, ar.rqdata, self.disabled_fields)
         ar.ah.store.form2obj(ar, ar.rqdata, self, False)
         self.full_clean()
+        pre_ui_save.send(sender=self.__class__, instance=self, ar=ar)
+        self.before_ui_save(ar, watcher)
         self.save_watched_instance(ar, watcher)
 
     @classmethod
@@ -1369,6 +1376,7 @@ def make_remote_field(model, name):
     cls = model
     field_chain = []
     editable = False
+    gettable = True
     leaf_chooser = None
     for n in parts:
         if model is None:
@@ -1395,6 +1403,9 @@ def make_remote_field(model, name):
             # dummy field
             return fld
 
+        if isinstance(fld, models.ManyToOneRel):
+            gettable = False
+
         # make sure that the atomizer gets created.
         store.get_atomizer(model, fld, fld.name)
 
@@ -1410,6 +1421,9 @@ def make_remote_field(model, name):
         else:
             model = None
 
+    if not gettable:
+        return RemoteField(none_getter, name, fld)
+
     if leaf_chooser is not None:
         d = choosers.get_choosers_dict(cls)
         d[name] = leaf_chooser
@@ -1564,3 +1578,5 @@ def choices_for_field(ar, holder, field):
     else:
         raise http.Http404("No choices for %s" % field)
     return (qs, row2dict)
+
+from lino_xl.lib.measurements.fields import MeasurementField
