@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2020 Rumma & Ko Ltd
+# Copyright 2009-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """This defines the :class:`Kernel` class.
@@ -120,7 +120,11 @@ class Kernel(object):
         # codetime watches only those modules which are already
         # imported.
         if self._code_mtime is None:
-            self._code_mtime = codetime()
+            if self.site.is_demo_site:
+                self._code_mtime = codetime()
+            else:
+                self._code_mtime = os.stat(import_module(
+                    os.environ['DJANGO_SETTINGS_MODULE']).__file__).st_mtime
         return self._code_mtime
 
     @property
@@ -148,6 +152,9 @@ class Kernel(object):
                         version[i] += v[i]
                         if i == 2:
                             break
+            rn = [int(num) for num in self.site.revision_number.split('.')]
+            for i in range(rn):
+                version[i] = version[i] + rn[i]
             version = [str(num) for num in version]
             self._lino_version = '.'.join(version)
         return self._lino_version
@@ -325,19 +332,19 @@ class Kernel(object):
                             f.remote_field, f.remote_field.model))
                     f.remote_field.model._lino_ddh.add_fk(m or model, f)
 
-            if not site.quick_startup:
-                fieldnames = {f.name for f in model._meta.get_fields()}
-                # print("20190627 checking ", model, fieldnames)
-                for m, k, v in class_dict_items(model):
-                    if isinstance(v, fields.VirtualField) and k in fieldnames:
-                        f = model._meta.get_field(k)
-                        if f.__class__ is v.__class__:
-                            # a copy of the virtual field in parent has already been attached
-                            # print("20190627 ignoring", m, k, v, f)
-                            continue
-                        raise ChangedAPI(
-                            "{} field {}.{} hidden by virtual field of same name.".format(
-                                f.__class__.__name__, fmn(model), k))
+            # if not site.quick_startup:
+            #     fieldnames = {f.name for f in model._meta.get_fields()}
+            #     # print("20190627 checking ", model, fieldnames)
+            #     for m, k, v in class_dict_items(model):
+            #         if isinstance(v, fields.VirtualField) and k in fieldnames:
+            #             f = model._meta.get_field(k)
+            #             if f.__class__ is v.__class__:
+            #                 # a copy of the virtual field in parent has already been attached
+            #                 # print("20190627 ignoring", m, k, v, f)
+            #                 continue
+            #             raise ChangedAPI(
+            #                 "{} field {}.{} hidden by virtual field of same name.".format(
+            #                     f.__class__.__name__, fmn(model), k))
 
         self.protect_foreignkeys(models_list)
 
@@ -786,6 +793,8 @@ class Kernel(object):
                 # logger.info("run_action {0}".format(ar))
         try:
             a.run_from_ui(ar)
+            if ar.request.method != 'GET' and ar.master_instance is not None and len(ar.selected_rows):
+                ar.set_response(master_data=ar.selected_rows[0].get_master_data(ar))
             if a.parameters and not a.no_params_window:
                 ar.set_response(close_window=True)
         except exceptions.ValidationError as e:
