@@ -726,6 +726,48 @@ class ColumnsLayout(FieldLayout):
     """
     join_str = " "
 
+    # def __init__(self, main=None, datasource=None,
+    #              hidden_elements=None, **kw):
+    #     if datasource is not None and hasattr(
+    #         datasource.model, 'previewable_field'
+    #     ) and main is not None:
+    #         columns = main.split()
+    #         if datasource.model.previewable_field in columns:
+    #             main, hidden_elements = self.set_previewable_columns(
+    #                 columns, datasource, hidden_elements)
+    #     super().__init__(main=main, datasource=datasource,
+    #                  hidden_elements=hidden_elements, **kw)
+
+    def set_previewable_columns(self, columns, actor, hidden_elements):
+        for i, name in enumerate(columns):
+            if name == actor.model.previewable_field:
+                pf_index = i
+                break
+        short_preview = actor.model.previewable_field + '_short_preview'
+        full_preview = actor.model.previewable_field + '_full_preview'
+
+        def remove_preview(preview, hidden_elements):
+            if preview in columns:
+                for i, name in enumerate(columns):
+                    if name == preview:
+                        p_index = i
+                        break
+                columns.remove(preview)
+                if p_index < pf_index:
+                    pf_index -= 1
+            else:
+                if hidden_elements is None:
+                    hidden_elements = set()
+                hidden_elements.add(preview)
+
+        remove_preview(short_preview, hidden_elements)
+        remove_preview(full_preview, hidden_elements)
+        columns.insert(pf_index + 1, short_preview)
+        columns.insert(pf_index + 2, full_preview)
+
+        main = ' '.join(columns)
+        return main, hidden_elements
+
     def set_datasource(self, ds):
         if ds is None:
             raise Exception("20130327 No datasource for %r" % self)
