@@ -11,7 +11,7 @@ from django.conf import settings
 from lino.core.utils import obj2str
 from lino.core.actors import resolve_action
 from lino.core.boundaction import BoundAction
-from lino.core.actions import QuickLinkAction
+from lino.core.actions import WrappedAction
 
 
 class QuickLinksList:
@@ -21,7 +21,7 @@ class QuickLinksList:
 
     def add_action(self, ba, **kwargs):
         ba = resolve_action(ba)
-        a = QuickLinkAction(ba, **kwargs)
+        a = WrappedAction(ba, **kwargs)
         self.items.append(a)
 
 
@@ -297,9 +297,9 @@ class Menu(MenuItem):
     def add_item(self, name, label, **kw):
         return self.add_item_instance(MenuItem(name, label, **kw))
 
-    def add_separator(self, label='-', **kw):
-        if len(self.items) > 0 and not self.items[-1].label.startswith('-'):
-            return self.add_item_instance(MenuItem(None, label, **kw))
+    def add_separator(self, **kw):
+        if len(self.items) > 0 and not self.items[-1].label == '-':
+            return self.add_item_instance(MenuItem(None, '-', **kw))
 
     def add_menu(self, name, label, **kw):
         return self.add_item_instance(Menu(
