@@ -1,12 +1,10 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2013-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# Copyright 2013-2021 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 """
 This defines the :class:`MergeAction` class.
 
-This action is automatically installed on every model except those that have
-:attr:`allow_merge_action <lino.core.model.Model.allow_merge_action>` set to
-False. For example it should not be used on models that have MTI children.
+See :doc:`/dev/merge`.
 
 """
 
@@ -14,8 +12,8 @@ import logging ; logger = logging.getLogger(__name__)
 
 from django.db import models
 from django.conf import settings
-from django.utils.translation import ugettext_lazy as _
-from django.utils.translation import ugettext
+from django.utils.translation import gettext_lazy as _
+from django.utils.translation import gettext
 
 from lino.core import actions
 from lino.core import layouts
@@ -28,11 +26,6 @@ from lino.api import rt
 
 
 class MergeAction(actions.Action):
-    """Merge this object into another object of same class.
-
-    This action has a dynamically generated parameters window.
-
-    """
     label = _("Merge")
     icon_name = 'arrow_join'
     ui5_icon_name = "sap-icon://font-awesome-solid/code-branch"
@@ -197,11 +190,11 @@ class MergePlan(object):
             if len(parts) != 0:
                 items.append(E.li(', '.join(parts), ' ', E.b(prefix)))
 
-        collect_summary(ugettext("will be deleted."), self.volatiles)
-        collect_summary(ugettext("will get reassigned."),
+        collect_summary(gettext("will be deleted."), self.volatiles)
+        collect_summary(gettext("will get reassigned."),
                         self.related + self.generic_related)
-        items.append(E.li(ugettext("%s will be deleted") % self.obj))
-        msg = ugettext("Are you sure you want to merge "
+        items.append(E.li(gettext("%s will be deleted") % self.obj))
+        msg = gettext("Are you sure you want to merge "
                 "%(this)s into %(merge_to)s?") % dict(
                     this=self.obj, merge_to=self.merge_to)
         if len(items) != 0:
