@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2021 Rumma & Ko Ltd
+# Copyright 2009-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """Defines the :class:`Model` class.
@@ -63,6 +63,8 @@ class Model(models.Model, fields.TableRow):
 
     allow_merge_action = False
 
+    master_data_fields = None
+
     show_in_site_search = True
 
     quick_search_fields = None
@@ -118,6 +120,15 @@ class Model(models.Model, fields.TableRow):
     def as_list_item(self, ar):
         return E.li(str(self))
 
+    def get_master_data(self, ar, master_instance=None):
+        if master_instance is None:
+            master_instance = ar.master_instance
+        if master_instance is not None and self.master_data_fields is not None:
+            rv = {}
+            for mdf in self.master_data_fields:
+                rv[mdf] = getattr(master_instance, mdf)
+            return rv
+
     @classmethod
     def collect_virtual_fields(model):
         """Declare every virtual field defined on this model to Django.
@@ -471,8 +482,8 @@ class Model(models.Model, fields.TableRow):
 
     def save_watched_instance(elem, ar, watcher):
         if watcher.is_dirty():
-            pre_ui_save.send(sender=elem.__class__, instance=elem, ar=ar)
-            elem.before_ui_save(ar, watcher)
+            # pre_ui_save.send(sender=elem.__class__, instance=elem, ar=ar)
+            # elem.before_ui_save(ar, watcher)
             elem.save(force_update=True)
             watcher.send_update(ar)
             ar.success(_("%s has been updated.") % obj2unicode(elem))
@@ -595,7 +606,7 @@ class Model(models.Model, fields.TableRow):
 
     def as_summary_row(self, ar):
         # used by tickets.Tickets table in the bootstrap frontend
-        # also when display_mode = constants.DISPLAY_MODE_STORY it returns html
+        # also when display_mode_main = constants.DISPLAY_MODE_STORY it returns html
         # text for the object that is calling
         if self.summary_row_template:
             # not tested
