@@ -252,7 +252,7 @@ class HtmlRenderer(Renderer):
         """
         if not nosummary:
             if display_mode is None:
-                display_mode = ar.actor.display_mode
+                display_mode = ar.actor.display_mode_main
             if display_mode == 'summary':
                 yield ar.actor.get_table_summary(ar.master_instance, ar)
                 return
@@ -477,7 +477,14 @@ class HtmlRenderer(Renderer):
         label = label or ba.get_button_label()
         if ar._status is None:
             ar._status = ar.get_status()
-        js = self.ar2js(ar, obj, **ar._status)
+        js_handler = ba.action.js_handler
+        if js_handler:
+            if callable(js_handler):
+                js = js_handler(ba.actor)
+            else:
+                js = js_handler
+        else:
+            js = self.ar2js(ar, obj, **ar._status)
         uri = self.js2url(js)
         return self.href_button_action(
             ba, uri, label, title or ba.action.help_text, **kwargs)
@@ -700,7 +707,7 @@ class TextRenderer(HtmlRenderer):
         :meth:`ar.show <lino.core.request.BaseRequest.show>`.
         """
         if display_mode is None:
-            display_mode = ar.actor.display_mode
+            display_mode = ar.actor.display_mode_main
         # if ar.actor.master is not None and not nosummary:
         if not nosummary:
             if display_mode == constants.DISPLAY_MODE_SUMMARY:
@@ -715,10 +722,7 @@ class TextRenderer(HtmlRenderer):
         if display_mode == constants.DISPLAY_MODE_CARDS:
             for row in ar.sliced_data_iterator:
                 txt = ar.get_card_title(row)
-                print(txt)
-                print("=" * len(txt))
                 ar.show_detail(row, display_mode=display_mode)
-                print()
             # rows = [ar.show_detail]
             return
 
