@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2021 Rumma & Ko Ltd
+# Copyright 2009-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 """
 See introduction in :doc:`/dev/ar`.
@@ -7,7 +7,8 @@ See introduction in :doc:`/dev/ar`.
 
 import logging; logger = logging.getLogger(__name__)
 
-from copy import copy
+from types import GeneratorType
+from copy import copy, deepcopy
 from xml.sax.saxutils import escape
 
 from django.conf import settings
@@ -111,6 +112,7 @@ class ValidActionResponses(object):
     """
 
     refresh = None
+    refresh_delayed_value = None
     refresh_all = None
     close_window = None
     record_deleted = None
@@ -138,6 +140,8 @@ class ValidActionResponses(object):
     Open the given URL in a new browser window.
     """
 
+    master_data = None
+
     open_webdav_url = None
     info_message = None
     warning_message = None
@@ -256,6 +260,8 @@ class BaseRequest(object):
 
     xcallback_answers = {}
 
+    row_meta = None
+
     _status = None  # cache when get_status() is called multiple times
 
     def __init__(self, request=None, parent=None, hash_router=None,
@@ -346,6 +352,33 @@ class BaseRequest(object):
         if selected_pks is not None:
             self.set_selected_pks(*selected_pks)
 
+        self.row_meta = dict(meta=True)
+
+    def get_row_classes(self, row):
+        if self.actor is None or self.actor.get_row_classes is None:
+            return
+        classes = self.actor.get_row_classes(row, self)
+        if isinstance(classes, GeneratorType):
+            row_classes = " ".join([klass for klass in classes])
+        else:
+            row_classes = classes
+        self.row_meta['styleClass'] = row_classes
+        return row_classes
+
+    def scrap_row_meta(self, row, row_items):
+        self.get_row_classes(row)
+        meta_exists = False
+        for i, item in enumerate(row_items):
+            if isinstance(item, dict) and item.get('meta', False):
+                meta_exists, meta_index = True, i
+                break
+        meta = deepcopy(self.row_meta)
+        if meta_exists:
+            row_items[meta_index] = meta
+        else:
+            row_items.append(meta)
+        self.row_meta = dict(meta=True)
+
     def parse_req(self, request, rqdata, **kw):
         """
         Parse the given incoming HttpRequest and set up this action
@@ -869,13 +902,13 @@ class BaseRequest(object):
                      .e.g. in :ref:`avanti.specs.roles` where we want
                      to show whether cells are clickable or not.
 
-        :nosummary: if it is a table with :attr:`display_mode
-                    <lino.core.tables.AbstractTable.display_mode>`
+        :nosummary: if it is a table with :attr:`display_mode_main
+                    <lino.core.tables.AbstractTable.display_mode_main>`
                     set to ``'summary'``, force rendering it as a
                     table.
 
-        :display_mode: override the table's :attr:`display_mode
-                       <lino.core.tables.AbstractTable.display_mode>`.
+        :display_mode: override the table's :attr:`display_mode_main
+                       <lino.core.tables.AbstractTable.display_mode_main>`.
 
                        Unlike `nosummary` this can be used to ask a summary for
                        a table that would not show as summary by default.
