@@ -1,5 +1,5 @@
-# Copyright 2011-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# Copyright 2011-2021 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """Defines built-in user roles. See :ref:`permissions`.
 
@@ -49,8 +49,9 @@ class SiteUser(UserRole):
     """Every authenticated user has this role."""
 
 class Expert(SiteUser):
-    """A user with some expertise."""
-
+    """
+    A user with some expertise and more options than a beginner.
+    """
 
 class SiteStaff(Expert):
     """
