@@ -139,12 +139,12 @@ class StoreField(object):
         # params.update(text=force_str(v))
         # tc.addElement(odf.text.P(**params))
 
-    def parse_form_value(self, v, obj):
+    def parse_form_value(self, v, obj, ar=None):
         # if v == '' and not self.field.empty_strings_allowed:
         #     return None
         return self.field.to_python(v)
 
-    def extract_form_data(self, obj, post_data):
+    def extract_form_data(self, obj, post_data, ar=None):
         # logger.info("20130128 StoreField.extract_form_data %s",self.name)
         return post_data.get(self.name, None)
 
@@ -157,7 +157,7 @@ class StoreField(object):
         - setting a Person.city to blank must not create a new Place "Select a Place..."
 
         """
-        v = self.extract_form_data(instance, post_data)
+        v = self.extract_form_data(instance, post_data, ar)
         # if self.name in 'nationality city':
         #     logger.info("20210213 %s.form2obj() %s = %r from %s",
         #                 self.__class__.__name__, self.name, v, post_data)
@@ -173,7 +173,7 @@ class StoreField(object):
             elif self.field.null:
                 v = None
             elif self.field.empty_strings_allowed:
-                v = self.parse_form_value(v, instance)
+                v = self.parse_form_value(v, instance, ar)
 
                 # If a field has been posted with empty string, we
                 # don't want it to get the field's default value!
@@ -186,7 +186,7 @@ class StoreField(object):
                 v = self.form2obj_default
             # print("20160611 {0} = {1}".format(self.field.name, v))
         else:
-            v = self.parse_form_value(v, instance)
+            v = self.parse_form_value(v, instance, ar)
         # logger.info("20180712 %s %s", self, v)
         if not is_new and self.field.primary_key and instance.pk is not None:
             if instance.pk == v:
@@ -262,7 +262,7 @@ class ComboStoreField(StoreField):
         yield self.name
         yield self.name + constants.CHOICES_HIDDEN_SUFFIX
 
-    def extract_form_data(self, obj, post_data):
+    def extract_form_data(self, obj, post_data, ar=None):
         return post_data.get(self.name + constants.CHOICES_HIDDEN_SUFFIX, None)
 
     # def obj2list(self,request,obj):
@@ -313,7 +313,7 @@ class ForeignKeyStoreField(RelatedMixin, ComboStoreField):
             return (v.pk, self.format_value(ar, v))
             #return (v.pk, str(v))
 
-    def extract_form_data(self, obj, post_data):
+    def extract_form_data(self, obj, post_data, ar=None):
         # logger.info("20130128 ComboStoreField.extract_form_data %s",self.name)
         pk = post_data.get(self.name + constants.CHOICES_HIDDEN_SUFFIX, None)
         if pk is None:
@@ -346,11 +346,11 @@ class ForeignKeyStoreField(RelatedMixin, ComboStoreField):
                 ch = obj.__class__.get_chooser_for_field(self.field.name)
                 if ch and ch.can_create_choice:
                     # print("20200901 can_create_choice", obj, v)
-                    return ch.create_choice(obj, pk)
+                    return ch.create_choice(obj, pk, ar)
 
         raise Warning("Got invalid non-empty pk {} for {}".format(pk, self))
 
-    def parse_form_value(self, v, obj):
+    def parse_form_value(self, v, obj, ar=None):
         """Convert the form field value (expected to contain a primary key)
         into the corresponding database object. If it is an invalid
         primary key, return None.
@@ -382,7 +382,7 @@ class ForeignKeyStoreField(RelatedMixin, ComboStoreField):
             ch = obj.__class__.get_chooser_for_field(self.field.name)
             if ch and ch.can_create_choice:
                 # print("20200901 can_create_choice", obj, v)
-                return ch.create_choice(obj, v)
+                return ch.create_choice(obj, v, ar)
         return None
 
 # class OneToOneStoreField(ForeignKeyStoreField):
@@ -402,23 +402,35 @@ class PreviewTextStoreField(StoreField):
     list_values_count = 3
 
     def column_names(self):
-        # yield self.options['name']
-        # yield self.options['name'] + constants.CHOICES_HIDDEN_SUFFIX
         yield self.name
         yield self.name + "_short_preview"
         yield self.name + "_full_preview"
 
     def value2list(self, ar, v, l, row):
-        if isinstance(row, PhantomRow):
-            l.append(None)
+        if ar.renderer.front_end.media_name.startswith('ext'):
+            super().value2list(ar, v, l, row)
         else:
-            l.append(getattr(row, self.name))
+            if isinstance(row, PhantomRow):
+                l.extend([None for _ in range(self.list_values_count)])
+            else:
+                l.extend([getattr(row, name) for name in self.column_names()])
 
     def value2dict(self, ar, k, v, d, row):
         if not isinstance(row, PhantomRow):
-            d[self.name] = getattr(row, self.name)
-            d[self.name+ "_short_preview"] = getattr(row, self.name+ "_short_preview")
-            d[self.name+ "_full_preview"] = getattr(row, self.name+ "_full_preview")
+            for name in self.column_names():
+                d[name] = getattr(row, name)
+
+class MeasurementStoreField(StoreField):
+
+    def extract_form_data(self, obj, post_data, ar=None):
+        unit = self.field.measurement.STANDARD_UNIT
+        if hasattr(obj, 'unit'):
+            new_unit = post_data.get('unitHidden', None)
+            if new_unit is not None:
+                unit = new_unit
+            elif obj.unit is not None:
+                unit = obj.unit.name
+        return self.field.measurement(**{unit: float(post_data.get(self.name, "0.0"))})
 
 
 # class LinkedForeignKeyField(ForeignKeyStoreField):
@@ -540,7 +552,7 @@ class SpecialStoreField(StoreField):
         self.options = dict(name=self.name)
         self.store = store
 
-    def parse_form_value(self, v, instance):
+    def parse_form_value(self, v, instance, ar=None):
         pass
 
     def form2obj(self, ar, instance, post_data, is_new):
@@ -683,7 +695,7 @@ class BooleanStoreField(StoreField):
             self.full_value_from_object = curry(
                 full_value_from_object, self)
 
-    def parse_form_value(self, v, obj):
+    def parse_form_value(self, v, obj, ar=None):
         """
         Ext.ensible CalendarPanel sends boolean values as
         """
@@ -710,7 +722,7 @@ class GenericForeignKeyField(DisplayStoreField):
             return str(v)
         return ar.obj2html(v)
 
-    def parse_form_value(self, v, obj):
+    def parse_form_value(self, v, obj, ar=None):
         v = getattr(obj, self.name, None)
         return v
 
@@ -744,7 +756,7 @@ class DecimalStoreField(StoreField):
         # kw['type'] = 'float'
         # StoreField.__init__(self,field,name,**kw)
 
-    def parse_form_value(self, v, obj):
+    def parse_form_value(self, v, obj, ar=None):
         return parse_decimal(v)
 
     # def value2num(self,v):
@@ -795,7 +807,7 @@ class DateStoreField(StoreField):
         kw['dateFormat'] = settings.SITE.date_format_extjs
         StoreField.__init__(self, field, name, **kw)
 
-    def parse_form_value(self, v, obj):
+    def parse_form_value(self, v, obj, ar=None):
         if v:
             v = datetime.date(*settings.SITE.parse_date(v))
         else:
@@ -812,7 +824,7 @@ class DateStoreField(StoreField):
 
 class IncompleteDateStoreField(StoreField):
 
-    def parse_form_value(self, v, obj):
+    def parse_form_value(self, v, obj, ar=None):
         if v:
             v = IncompleteDate(*settings.SITE.parse_date(v))
             # v = datetime.date(*settings.SITE.parse_date(v))
@@ -821,7 +833,7 @@ class IncompleteDateStoreField(StoreField):
 
 class DateTimeStoreField(StoreField):
 
-    def parse_form_value(self, v, obj):
+    def parse_form_value(self, v, obj, ar=None):
         if v:
             return settings.SITE.parse_datetime(v)
         return None
@@ -829,7 +841,7 @@ class DateTimeStoreField(StoreField):
 
 class TimeStoreField(StoreField):
 
-    def parse_form_value(self, v, obj):
+    def parse_form_value(self, v, obj, ar=None):
         if v:
             return settings.SITE.parse_time(v)
         return None
@@ -1027,6 +1039,8 @@ def create_atomizer(holder, fld, name):
         return DisplayStoreField(fld, name)
     if isinstance(fld, models.IntegerField):
         return IntegerStoreField(fld, name)
+    if isinstance(fld, fields.MeasurementField):
+        return MeasurementStoreField(fld, name)
     if isinstance(fld, fields.PreviewTextField):
         return PreviewTextStoreField(fld, name)
     if isinstance(fld, models.ManyToOneRel):
@@ -1356,6 +1370,8 @@ class Store(BaseStore):
                 else:
                     v = fld.full_value_from_object(row, ar)
                 fld.value2list(ar, v, l, row)
+
+            ar.scrap_row_meta(row, l)
         # logger.info("20130611 Store row2list() --> %r", l)
         return l
 
