@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2020 Rumma & Ko Ltd
+# Copyright 2009-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """Defines the classes :class:`AbstractTable` and
@@ -7,6 +7,7 @@
 
 """
 import logging ; logger = logging.getLogger(__name__)
+from future.utils import with_metaclass
 
 import os
 import yaml
@@ -18,6 +19,8 @@ from django.utils.translation import gettext_lazy as _
 from lino.core import actors
 from lino.core import actions
 from lino.core import fields
+from lino.core import constants
+from lino.core.classproperty import classproperty
 from lino.core.utils import resolve_fields_list
 from lino.core.tablerequest import TableRequest
 
@@ -318,7 +321,28 @@ class AbstractTable(actors.Actor):
     Usually such a warning means that there is something wrong.
     """
 
-    display_mode = 'grid'
+    display_mode_main = constants.DISPLAY_MODE_TABLE
+    """
+    The default display_mode when the Table is the `main` layout element.
+    """
+
+    _display_mode_slave = None
+
+    @classproperty
+    def display_mode_slave(cls):
+        """
+
+        The display_mode when the Table is something other then the `main`
+        layout element.
+
+        """
+        if cls._display_mode_slave is None:
+            return cls.display_mode_main
+        return cls._display_mode_slave
+
+    @display_mode_slave.setter
+    def display_mode_slave(cls, value):
+        cls._display_mode_slave = value
 
     max_render_depth = 2
     """
