@@ -71,8 +71,8 @@ if is_devserver():
     if not settings.DEBUG:
         urlpatterns += static(
             settings.STATIC_URL, document_root=settings.STATIC_ROOT)
-        print("20210812 serve static %s -> %s" % (
-            settings.STATIC_URL, settings.STATIC_ROOT))
+        # print("20210812 serve static %s -> %s" % (
+        #     settings.STATIC_URL, settings.STATIC_ROOT))
 
     # pat = r'^{0}(?P<path>.*)$'.format(settings.STATIC_URL[1:])
     # urlpatterns.append(url(pat, serve))
