@@ -1,13 +1,13 @@
     # -*- coding: UTF-8 -*-
 # Copyright 2012-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 """
 Defines the classes used for defining workflows.  See
 :doc:`/dev/workflows`.
 """
 
 from django.utils.functional import Promise
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.utils.text import format_lazy
 from django.db import models
 
