@@ -3,6 +3,8 @@
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import os
+import shutil
+from pathlib import Path
 
 import warnings
 warnings.filterwarnings(
@@ -16,6 +18,7 @@ from django.conf import settings
 from django.core.management import call_command
 from django.core.management.base import BaseCommand, CommandError
 from django.db.utils import IntegrityError, OperationalError
+from django.db.migrations.exceptions import CircularDependencyError
 from django.core.management.color import no_style
 # ~ from django.core.management.sql import sql_reset
 from django.db import connections, transaction, DEFAULT_DB_ALIAS
@@ -176,14 +179,31 @@ Are you sure (y/n) ?""" % dbname):
         settings.SITE._site_config = None  # clear cached instance
 
         if engine == 'django.db.backends.postgresql':
-        #     # a first time to create tables of contenttypes. At
-        #     # least on PostgreSQL this is required because for
-        #     # some reason the syncdb fails when contenttypes is
-        #     # not initialized.
+            # a first time to create tables of contenttypes. At
+            # least on PostgreSQL this is required because for
+            # some reason the syncdb fails when contenttypes is
+            # not initialized.
             call_command('migrate', **options)
-        call_command('makemigrations', interactive=False, verbosity=0)
+            for p in settings.SITE.installed_plugins:
+                if p.app_name.startswith('lino'):
+                    migrations_dir = Path(p.app_module.__file__).parent / 'migrations'
+                    # if not migrations_dir.exists():
+                    os.mkdir(migrations_dir)
+                    try:
+                        call_command('makemigrations', p.app_name.split('.')[-1], interactive=False, verbosity=0)
+                    except CircularDependencyError as e:
+                        pass
+        else:
+            call_command('makemigrations', interactive=False, verbosity=0)
         call_command('migrate', '--run-syncdb', **options)
 
+        if engine == 'django.db.backends.postgresql':
+            for p in settings.SITE.installed_plugins:
+                if p.app_name.startswith('lino'):
+                    migrations_dir = Path(p.app_module.__file__).parent / 'migrations'
+                    if migrations_dir.exists():
+                        shutil.rmtree(migrations_dir)
+
         if len(fixtures):
             # if engine == 'django.db.backends.postgresql':
             #     foralltables(using, "ALTER TABLE {} DISABLE TRIGGER ALL;")
