@@ -35,15 +35,14 @@ class Command(BaseCommand):
 
     def handle(self, *args, **options):
         reqs = set(settings.SITE.get_requirements())
+        reqs = sorted(reqs)
+        if options['list']:
+            print('\n'.join(reqs))
+            return
         if len(reqs) == 0:
             print("No requirements")
-        else:
-            reqs = sorted(reqs)
-            if options['list']:
-                print('\n'.join(reqs))
-                return
-            runcmd('pip install --upgrade pip')
-            # cmd = "pip install --upgrade --trusted-host svn.forge.pallavi.be {}".format(' '.join(reqs))
-            cmd = "pip install --upgrade {}".format(' '.join(reqs))
-            if not options['interactive'] or confirm("{} (y/n) ?".format(cmd)):
-                runcmd(cmd)
+            return
+        # cmd = "pip install --upgrade --trusted-host svn.forge.pallavi.be {}".format(' '.join(reqs))
+        cmd = sys.executable + " -m pip install --upgrade pip {}".format(' '.join(reqs))
+        if not options['interactive'] or confirm("{} (y/n) ?".format(cmd)):
+            runcmd(cmd)
