@@ -2,6 +2,7 @@
 # Copyright 2013-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
+from django.core.management import call_command
 from django.conf import settings
 from django.db import DEFAULT_DB_ALIAS
 from lino.management.commands.initdb import Command as BaseCommand
@@ -27,5 +28,9 @@ class Command(BaseCommand):
         if isinstance(args, str):
             args = args.split()
         options['fixtures'] = args
+
+        if settings.SITE.is_installed('search') and settings.SITE.use_elasticsearch:
+            call_command('createindexes', '-i')
+
         # super(Command, self).handle(*args, **options)
         super(Command, self).handle(**options)
