@@ -27,13 +27,13 @@ from django.utils.text import format_lazy
 from django.utils import timezone
 from django.contrib.humanize.templatetags.humanize import naturaltime
 
+from lino.core import actions
 from lino.core import fields
 from lino.core import model
 from lino.core.workflows import ChangeStateAction
 from lino.utils.mldbc.fields import LanguageField
 from lino.core.exceptions import ChangedAPI
 
-
 class Contactable(model.Model):
     """
     Mixin for models that represent somebody who can be contacted by
@@ -244,6 +244,22 @@ class Story(model.Model):
             self.get_story(apr.ar), master_instance=self))
         return str('').join(chunks)  # must be utf8 encoded
 
+class DragAndDrop(actions.Action):
+    select_rows = True
+    show_in_bbar = False
+
+    def run_from_ui(self, ar, **kw):
+        obj = ar.selected_rows[0]
+        obj.on_dropped(ar, **kw)
+
+class Draggable(model.Model):
+    class Meta:
+        abstract = True
+
+    drag_drop = DragAndDrop()
+
+    def on_dropped(self, ar, **kwargs):
+        pass
 
 
 
