@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2014-2021 Rumma & Ko Ltd
+# Copyright 2014-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
@@ -261,8 +261,8 @@ DupableChecker.activate()
 
 class SimilarObjects(dd.VirtualTable):
     """Shows the other objects which are similar to this one."""
-    # display_mode = 'html'
-    display_mode = 'summary'
+    # display_mode_main = 'html'
+    display_mode_main = 'summary'
     master = dd.Model
     abstract = True
 
