@@ -1,19 +1,18 @@
 # -*- coding: utf-8 -*-
 # Copyright 2008-2020 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 """
 
 See test cases and examples in :doc:`/specs/human`.
 
 """
-from past.utils import old_div
 
 import datetime
 from dateutil.relativedelta import relativedelta
 
 from django.db import models
 from django.core.exceptions import ValidationError
-from django.utils.translation import ugettext_lazy as _
+from django.utils.translation import gettext_lazy as _
 from django.utils.translation import pgettext_lazy as pgettext
 from django.conf import settings
 
@@ -380,7 +379,7 @@ class Born(model.Model):
             except ValueError:
                 pass
 
-    @fields.displayfield(_("Age"))
+    @fields.displayfield(_("Age"), wildcard_data_elem=True)
     def age(self, ar, today=None):
         a = self.get_exact_age(today)
         if a is None:
