@@ -72,23 +72,27 @@ class About(EmptyTable):
                 dd.fdf(settings.SITE.the_demo_date))
             body.append(E.p(s))
 
-        feats = settings.SITE.features.features
-        body.append(E.h4(str(_("Available Features:"))))
-        style = "border: 1px solid black; border-radius: 2px; padding: 5px;"
-
-        f_table_head = []
-        f_table_head.append(E.th(str(_("Feature")), style=style))
-        f_table_head.append(E.th(str(_("Description")), style=style))
-        f_table_head.append(E.th(str(_("Status")), style=style))
-        thead = E.thead(E.tr(*f_table_head))
-        trs = []
-
-        for key in feats:
-            row = E.tr(E.td(key, style=style), E.td(str(feats[key]['description']), style=style),
-            E.td(str(_("Active")) if key in settings.SITE.features.active_features else str(_("Inactive")), style=style))
-            trs.append(row)
-        tbody = E.tbody(*trs)
-        body.append(E.table(thead, tbody))
+        features = []
+        for k, v in settings.SITE.features.items():
+            if v:
+                features.append(k)
+        body.append(E.p("{} : {}".format(
+            _("Enabled features:"), ", ".join(features))))
+        # style = "border: 1px solid black; border-radius: 2px; padding: 5px;"
+        #
+        # f_table_head = []
+        # f_table_head.append(E.th(str(_("Feature")), style=style))
+        # f_table_head.append(E.th(str(_("Description")), style=style))
+        # f_table_head.append(E.th(str(_("Status")), style=style))
+        # thead = E.thead(E.tr(*f_table_head))
+        # trs = []
+        #
+        # for key in feats:
+        #     row = E.tr(E.td(key, style=style), E.td(str(feats[key]['description']), style=style),
+        #     E.td(str(_("Active")) if key in settings.SITE.features.active_features else str(_("Inactive")), style=style))
+        #     trs.append(row)
+        # tbody = E.tbody(*trs)
+        # body.append(E.table(thead, tbody))
 
         body.append(E.p(str(_("Source timestamps:"))))
         items = []
