@@ -1,4 +1,5 @@
-# Copyright 2015-2021 Rumma & Ko Ltd
+# -*- coding: UTF-8 -*-
+# Copyright 2015-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from collections import OrderedDict
@@ -172,7 +173,7 @@ class ProblemsByOwner(Problems):
     """
     master_key = 'owner'
     column_names = "message checker user #fixable *"
-    display_mode = 'summary'
+    display_mode_main = 'summary'
 
 
 class ProblemsByChecker(Problems):
