@@ -7,7 +7,7 @@ from django.db.models import Q
 from django.core import validators
 from django.contrib.contenttypes.models import ContentType
 from django.conf import settings
-from etgen.html import E, tostring
+from etgen.html import E, tostring, fromstring
 
 from lino.api import dd, rt, _
 
@@ -147,6 +147,28 @@ class Comment(CreatedModified, UserAuthored, Controllable, ElasticSearchable,
         if mr:
             return mr.emotion
 
+    def as_story_item(self, ar):
+        header = [ar.obj2html(self, self.created_natural)]
+        header.append(str(_(" by ")))
+        header.append(ar.obj2html(self.user))
+        header.append(E.span(":"))
+        elems = [E.h3(*header)]
+        try:
+            full_preview_elem = fromstring(self.body_full_preview)
+        except:
+            full_preview_elem = fromstring("<p>" + self.body_full_preview + "</p>")
+
+        childs = []
+        if self.replies_to_this.count():
+            childs.append(E.h4("Replies:"))
+            for child in self.replies_to_this.all():
+                childs.append(fromstring(child.as_story_item(ar)))
+
+        elems.append(E.div(full_preview_elem, *childs, style="margin-left: 40px;"))
+
+        elems.append(E.br())
+        return tostring(E.div(*elems))
+
     def __str__(self):
         return '{} #{}'.format(self._meta.verbose_name, self.pk)
         # return _('{user} {time}').format(
