@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2013-2021 Rumma & Ko Ltd
+# Copyright 2013-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 from django.utils.translation import ngettext
@@ -15,6 +15,7 @@ from lino import mixins
 from lino.core.constants import CHOICES_BLANK_FILTER_VALUE, DISPLAY_MODE_STORY
 from lino.core.utils import qs2summary
 from lino.core.gfks import gfk2lookup
+from lino.core import constants
 from .roles import CommentsReader, CommentsUser, CommentsStaff
 from .choicelists import CommentEvents, Emotions
 from .fields import MyEmotionField
@@ -103,6 +104,16 @@ class Comments(dd.Table):
             yield p
         yield "reply_to"
 
+    @classmethod
+    def get_card_title(self, ar, obj):
+        """Overrides the default behaviour
+        """
+        title = _("Created {created} by {user}").format(
+            created=naturaltime(obj.created), user=str(obj.user))
+        if self.get_view_permission(ar.get_user().user_type):
+            title = tostring(ar.obj2html(obj, title))
+        return title
+
     # @classmethod
     # def get_table_summary(cls, obj, ar):
     #     # print("20190926 get_table_summary", ar.request)
@@ -125,8 +136,11 @@ class Comments(dd.Table):
             t = _("Modified " + comment.modified.strftime('%Y-%m-%d %H:%M'))
         ch.append(ar.obj2html(
             comment, naturaltime(comment.created), title=t))
-        ch += [" ", _("by"), " ",
-               ar.obj2html(comment.user, str(comment.user))]
+        if comment.user is None:
+            ch += [" ", _("by system")]
+        else:
+            ch += [" ", _("by"), " ",
+                   ar.obj2html(comment.user, str(comment.user))]
 
         sar = cls.insert_action.request_from(ar)
         # print(20170217, sar)
@@ -196,19 +210,12 @@ class CommentsByX(Comments):
     required_roles = dd.login_required(CommentsReader)
     order_by = ["-created"]
     # order_by = ["-modified"]
-    display_mode = "summary"
+    display_mode_main = "summary"
     # card_layout = dd.DetailLayout("""
     # card_summary
     # RepliesByComment
     # """)
 
-    @classmethod
-    def get_card_title(self, ar, obj):
-        """Overrides the default behaviour
-        """
-        return _("Created {created} by {user}").format(
-            created=naturaltime(obj.created), user=str(obj.user))
-
     @classmethod
     def get_request_queryset(cls, ar, **filter):
         qs = super(CommentsByX, cls).get_request_queryset(ar, **filter)
@@ -301,7 +308,10 @@ class CommentsByX(Comments):
 
         yield ar.obj2html(o, naturaltime(o.created), title=t)
         yield " {} ".format(_("by"))
-        by = o.user.username
+        if o.user is None:
+            by = gettext("system")
+        else:
+            by = o.user.username
         yield E.b(by)
 
 
@@ -311,7 +321,10 @@ class CommentsByX(Comments):
         if not ar.is_obvious_field('reply_to'):
             if o.reply_to:
                 yield " {} ".format(_("in reply to"))
-                yield E.b(o.reply_to.user.username)
+                if o.reply_to.user is None:
+                    yield gettext("system")
+                else:
+                    yield E.b(o.reply_to.user.username)
             if not ar.is_obvious_field('owner'):
                 if o.owner:
                     yield " {} ".format(_("about"))
@@ -359,7 +372,7 @@ class RecentComments(CommentsByX):
     # order_by = ["-modified"]
     label = _("Recent comments")
     preview_limit = 10
-    # display_mode = "summary"
+    # display_mode_main = "summary"
 
 
 class CommentsByType(CommentsByX):
@@ -371,7 +384,8 @@ class CommentsByRFC(CommentsByX):
     master_key = 'owner'
     column_names = "body created user *"
     stay_in_grid = True
-    # display_mode = "list"
+    display_mode_main = constants.DISPLAY_MODE_STORY
+    display_mode_slave = constants.DISPLAY_MODE_SUMMARY
     simple_slavegrid_header = True
     insert_layout = dd.InsertLayout("""
     reply_to
@@ -453,9 +467,9 @@ class CommentsByMentioned(CommentsByX):
 
 class RepliesByComment(CommentsByX):
     master_key = 'reply_to'
-    # display_mode = "list"
+    # display_mode_main = "list"
     stay_in_grid = True
-    # display_mode = DISPLAY_MODE_STORY
+    # display_mode_main = DISPLAY_MODE_STORY
     # title = _("Replies")
     label = _("Replies")
     simple_slavegrid_header = True
