@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2014-2017 Rumma & Ko Ltd
+# Copyright 2014-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """Defines the :class:`Dupable` model mixin and related functionality
@@ -112,8 +112,8 @@ class WordsByOwner(PhoneticWords):
 class SimilarObjects(dd.VirtualTable):
     """Shows the other objects which are similar to this one."""
     label = _("Similar objects")
-    # display_mode = 'html'
-    display_mode = 'summary'
+    # display_mode_main = 'html'
+    display_mode_main = 'summary'
     # master = dd.Model
     master = Dupable
 
