@@ -149,7 +149,7 @@ def test_version_mismatch(request):
         return {}
     # print("20201217", lv, settings.SITE.kernel.code_mtime)
     cache.clear()
-    if settings.SITE.kernel.default_ui.verbose_name == 'React':
+    if settings.SITE.kernel.default_ui.app_label == 'react':
         return dict(version_mismatch=True)
     return dict(alert=_("Version mismatch"),
                 message=_("Your browser is using a previous version of the site, press OK to reload the site"),
@@ -320,6 +320,9 @@ class ApiElement(View):
 
     @method_decorator(ensure_csrf_cookie)
     def get(self, request, app_label=None, actor=None, pk=None):
+        vm = test_version_mismatch(request)
+        if vm and settings.SITE.kernel.default_ui.app_label == 'react':
+            return json_response(vm)
         # this is also used by the react front end
         rpt = requested_actor(app_label, actor)
         # if not rpt.get_view_permission(request.user.user_type):
@@ -377,11 +380,7 @@ class ApiElement(View):
                         success=False, message=NOT_FOUND % (rpt, pk))
                 else:
                     datarec = ar.elem2rec_detailed(elem)
-                vm = test_version_mismatch(request)
-                if vm:
-                    datarec.update(vm)
-                    resp = json_response(datarec)
-                    return resp
+                datarec.update(**vm)
                 return json_response(datarec)
 
             after_show = ar.get_status(record_id=pk)
@@ -454,6 +453,9 @@ class ApiList(View):
 
     @method_decorator(ensure_csrf_cookie)
     def get(self, request, app_label=None, actor=None):
+        vm = test_version_mismatch(request)
+        if vm and settings.SITE.kernel.default_ui.app_label == 'react':
+            return json_response(vm)
         ar = action_request(app_label, actor, request, request.GET, True)
         ar.renderer = settings.SITE.kernel.extjs_renderer
         rh = ar.ah
@@ -490,11 +492,7 @@ class ApiList(View):
                 kw.update(
                     param_values=ar.actor.params_layout.params_store.pv2dict(
                         ar, ar.param_values))
-            vm = test_version_mismatch(request)
-            if vm:
-                kw.update(vm)
-                resp = json_response(kw)
-                return resp
+            kw.update(**vm)
             return json_response(kw)
 
         if fmt == constants.URL_FORMAT_HTML:
