@@ -24,7 +24,7 @@ class Plugin(Plugin):
 
     url_prefix = 'f'
 
-    def on_ui_init(self, ui):
+    def on_ui_init(self, kernel):
         from .renderer import Renderer
         self.renderer = Renderer(self)
         # ui.bs3_renderer = self.renderer
@@ -48,4 +48,3 @@ class Plugin(Plugin):
     def get_index_view(self):
         from . import views
         return views.Index.as_view()
-
