@@ -5,13 +5,13 @@
 <lino.modlib.langguages.models.Language>` model).
 
 It is used by :mod:`lino_xl.lib.cv`, whose :class:`LanguageKnowledge
-<lino_xl.lib.cv.models.LanguageKnowledge>` and :class:`Schooling
-<lino_xl.lib.cv.models.Schooling>` models have a `language` field
+<lino_xl.lib.cv.LanguageKnowledge>` and :class:`Schooling
+<lino_xl.lib.cv.Schooling>` models have a `language` field
 which points to this the :class:`Language
 <lino.modlib.langguages.models.Language>` model.
 
 Note that this has nothing to do with the list of languages in your
-:attr:`languages <lino.core.site.Site.languages>` setting.
+:setting:`languages` setting.
 
 
 .. autosummary::
