@@ -57,7 +57,7 @@ class Plugin(ad.Plugin):
 
         self.parser = Parser()
 
-        def url2html(parser, s):
+        def url2html(parser, s, cmdname, usages):
             url_text = s.split(None, 1)
             if len(url_text) == 1:
                 url = text = url_text[0]
