@@ -58,7 +58,7 @@ class Plugin(ad.Plugin):
             #    cld["ROUTING"] = "lino.modlib.notify.routing.channel_routing"
             #    cld["BACKEND"] = "asgiref.inmemory.ChannelLayer"
             #else:
-            sd['ASGI_APPLICATION'] = "lino.modlib.notify.routing2.application"
+            sd['ASGI_APPLICATION'] = "lino.modlib.notify.routing.application"
             cld["BACKEND"] = "channels_redis.core.RedisChannelLayer"
             cld['CONFIG'] = {"hosts": [("localhost", 6379)], }
             if False:  # not is_devserver():
@@ -160,54 +160,94 @@ class Plugin(ad.Plugin):
             // Note that the path doesn't matter for routing; any WebSocket
             // connection gets bumped over to WebSocket consumers
             var ws_scheme = window.location.protocol == "https:" ? "wss" : "ws";
-            var ws_path = window.location.pathname + "lino/";
+            var ws_path = "/WS/";
             console.log("Connecting to " + ws_path);
-            var webSocketBridge = new channels.WebSocketBridge();
-            var username = '%s' ;
-            webSocketBridge.connect();
-            lino_connecting = function() {
-                console.log("lino connecting ...");
-                webSocketBridge.send({
-                            "command": "user_connect",
-                            "username": username
-                        });
-            }
-            webSocketBridge.socket.addEventListener('open', function() {
-                lino_connecting();
-            });
-            // Helpful debugging
-            webSocketBridge.socket.onclose = function () {
-                console.log("Disconnected from chat socket");
-            }
-
-            onGranted = console.log("onGranted");
-            onDenied = console.log("onDenied");
-            // Ask for permission if it's not already granted
-            Push.Permission.request(onGranted,onDenied);
-
-            webSocketBridge.listen(function(action, stream) {
-                try {
-                    Push.create( %s , {
-                        body: action['body'],
-                        icon: '/static/img/lino-logo.png',
-                        onClick: function () {
-                            window.focus();
-                            """ + site.kernel.default_renderer.reload_js() + """
-                            this.close();
-                        }
-                    });
-                    if (false && Number.isInteger(action["id"])){
-                        webSocketBridge.stream('lino').send({message_id: action["id"]})
-                        webSocketBridge.send(JSON.stringify({
-                                        "command": "seen",
-                                        "message_id": action["id"],
-                                    }));
+            // var webSocketBridge = new channels.WebSocketBridge();
+            function connect() {
+                var webSocket = new WebSocket(ws_scheme + "://" + window.location.host + ws_path);
+                webSocket.addEventListener('open', (event) => {
+                    console.log(event);
+                });
+                webSocket.addEventListener('message', (event) => {
+                    let data = JSON.parse(event.data);
+                    if (data.type === "NOTIFICATION") {
+                        let onGranted = () => console.log("onGranted");
+                        let onDenied = () => console.log("onDenied");
+                        // Ask for permission if it's not already granted
+                        Push.Permission.request(onGranted, onDenied);
+                        let {body, subject, action_url} = data;
+                        try {
+                            Push.create(subject, {
+                                body: body,
+                                icon: '/static/img/lino-logo.png',
+                                onClick: function () {
+                                    window.open(action_url);
                                 }
+                            });
+                        }
+                        catch (err) {
+                            console.log(err.message);
+                        }
                     }
-                catch(err) {
-                    console.log(err.message);
-                }
-            })});
+                });
+                webSocket.addEventListener('close', (event) => {
+                    setTimeout(function() {
+                      connect();
+                    }, 1000);
+                });
+                webSocket.addEventListener('error', (event) => {
+                    setTimeout(function() {
+                      connect();
+                    }, 1000);
+                });
+            }
+            connect();
+            // var username = '%s' ;
+            // webSocketBridge.connect();
+            // lino_connecting = function() {
+            //     console.log("lino connecting ...");
+            //     webSocketBridge.send({
+            //                 "command": "user_connect",
+            //                 "username": username
+            //             });
+            // }
+            // webSocketBridge.socket.addEventListener('open', function() {
+            //     lino_connecting();
+            // });
+            // // Helpful debugging
+            // webSocketBridge.socket.onclose = function () {
+            //     console.log("Disconnected from chat socket");
+            // }
+            //
+            // onGranted = console.log("onGranted");
+            // onDenied = console.log("onDenied");
+            // // Ask for permission if it's not already granted
+            // Push.Permission.request(onGranted,onDenied);
+            //
+            // webSocketBridge.listen(function(action, stream) {
+            //     try {
+            //         Push.create( %s , {
+            //             body: action['body'],
+            //             icon: '/static/img/lino-logo.png',
+            //             onClick: function () {
+            //                 window.focus();
+            //                 """ + site.kernel.default_renderer.reload_js() + """
+            //                 this.close();
+            //             }
+            //         });
+            //         if (false && Number.isInteger(action["id"])){
+            //             webSocketBridge.stream('lino').send({message_id: action["id"]})
+            //             webSocketBridge.send(JSON.stringify({
+            //                             "command": "seen",
+            //                             "message_id": action["id"],
+            //                         }));
+            //                     }
+            //         }
+            //     catch(err) {
+            //         console.log(err.message);
+            //     }
+            // });
+        });
         // end of onReady()"
         </script>
             """) % (user_name, py2js(site_title))
