@@ -44,19 +44,20 @@ def send_notification(user=None, primary_key=None, subject=None, body=None,
             id=primary_key,
             body=body,
             created=created,
+            action_url=action_url
         )
 
         try:
             channel_layer = get_channel_layer()
-            async_to_sync(channel_layer.group_send)(str(user.pk),
-                                                    {"type": "send_notification",  # method name in consumer
+            async_to_sync(channel_layer.group_send)(user.username,
+                                                    {"type": "send.notification",  # method name in consumer
                                                      "text": json.dumps(msg)})  # data
         except Exception as E:
             logger.exception(E)
 
     elif dd.plugins.notify.use_push_api:
         data = dict(action_url=action_url, subject=subject, body=body, action_title=action_title)
-        logger.info("Push to %s : %s", user or "everyone", data)
+        # logger.info("Push to %s : %s", user or "everyone", data)
         kwargs = dict(
             data=json.dumps(data),
             vapid_private_key=dd.plugins.notify.vapid_private_key,
