@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2011-2021 Rumma & Ko Ltd
+# Copyright 2011-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 import logging ; logger = logging.getLogger(__name__)
@@ -113,6 +113,9 @@ if dd.plugins.notify.use_push_api:
 
 
 class Message(UserAuthored, Controllable, Created):
+
+    show_in_site_search = False
+
     class Meta(object):
         app_label = 'notify'
         verbose_name = _("Notification message")
@@ -367,10 +370,10 @@ class MyMessages(My, Messages):
     created_order = "-created"
     order_by = [created_order]
     # hide_headers = True
-    display_mode = 'summary'
+    display_mode_main = 'summary'
 
-    # display_mode = 'list'
-    # display_mode = 'grid'
+    # display_mode_main = 'list'
+    # display_mode_main = 'grid'
 
     @classmethod
     def get_table_summary(cls, mi, ar):
