@@ -35,14 +35,17 @@ class Plugin(ad.Plugin):
     user_type_verified = 'user'
     """The default user_type for a verified user."""
 
+    my_setting_text = _("My settings")
+
     # partner_model = 'contacts.Person'
     partner_model = 'contacts.Partner'
 
     @classmethod
-    def setup_site_features(self, feats):
-        feats.define_feature(
-            'third_party_authentication',
-            _("Whether to allow login using credentials from third party"))
+    def setup_site_features(self, site):
+        site.define_feature('third_party_authentication')
+        # feats.define_feature(
+        #     'third_party_authentication',
+        #     _("Whether to allow signing in using credentials from third party"))
 
     def on_site_startup(self, site):
         super(Plugin, self).on_site_startup(site)
@@ -70,7 +73,7 @@ class Plugin(ad.Plugin):
         super(Plugin, self).on_init()
         self.site.set_user_model('users.User')
         from lino.core.site import has_socialauth
-        if self.has_feature('third_party_authentication') and has_socialauth:
+        if self.site.has_feature('third_party_authentication') and has_socialauth:
             self.needs_plugins.append('social_django')
 
     def setup_config_menu(self, site, user_type, m):
