@@ -1,4 +1,4 @@
-# Copyright 2009-2016 Rumma & Ko Ltd
+# Copyright 2009-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """This defines Lino default settings. You include this (directly or
@@ -8,7 +8,7 @@ indirectly) into your local :xfile:`settings.py` using::
 
 """
 
-from lino.api.ad import Site, configure_plugin
+from lino.api.ad import Site
 # from lino.api import rt
 
 # from lino.modlib.users.models import User
