@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2002-2021 Rumma & Ko Ltd
+# Copyright 2002-2022 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """Some extensions for Sphinx.
@@ -18,8 +18,8 @@ import sys
 from pathlib import Path
 from typing import Any, Dict, List, Tuple
 
-from atelier import sphinxconf
-from atelier.sphinxconf import interproject
+from rstgen import sphinxconf
+from rstgen.sphinxconf import interproject
 from sphinx.ext import autosummary
 from sphinx.ext.autodoc.importer import import_module
 from sphinx.util import logging ; logger = logging.getLogger(__name__)
@@ -84,7 +84,7 @@ if False:
     autosummary._import_by_name = _import_by_name
 
 
-def configure(globals_dict, django_settings_module=None, project=None):
+def configure(globals_dict, django_settings_module=None):
     """
     Adds to your :xfile:`conf.py` an arbitrary series of things that all
     Lino docs configuration files have in common.
@@ -94,7 +94,7 @@ def configure(globals_dict, django_settings_module=None, project=None):
       from lino.sphinxcontrib import configure
       configure(globals())
 
-    This will also call :func:`atelier.sphinxconf.configure`, and then
+    This will also call :func:`rstgen.sphinxconf.configure`, and then
     adds more things specific to the Lino framework.
 
     This adds the main Lino doctrees to your `intersphinx_mapping
@@ -112,7 +112,9 @@ def configure(globals_dict, django_settings_module=None, project=None):
         from django.conf import settings
         print(settings.SITE.welcome_text())
 
-    sphinxconf.configure(globals_dict, project)
+    # Note that this configure() does *not* call atelier.sc.configure(). It can
+    # be used with either atelier.sc.configure() or rstgen.sc.configure()
+    # sphinxconf.configure(globals_dict, project)
 
     im = {}
     im['lf'] = ('https://www.lino-framework.org/', None)
@@ -124,5 +126,6 @@ def configure(globals_dict, django_settings_module=None, project=None):
 
     interproject.configure(globals_dict, **im)
 
-    extlinks = globals_dict['extlinks']
-    extlinks['ticket'] = ('https://jane.mylino.net/#/api/tickets/PublicTickets/%s', '#')
+    extlinks = globals_dict.setdefault('extlinks', dict())
+    extlinks['ticket'] = (
+        'https://jane.mylino.net/#/api/tickets/PublicTickets/%s', '#%s')
