@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2013-2014 Luc Saffre
-# License: BSD (see file COPYING for details)
+# Copyright 2013-2021 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """Sets the `html_logo` and `html_favicon` for all Lino-related sites.
 
@@ -11,19 +11,19 @@ Also adds some css styling.
 
 """
 
-from unipath import Path
+from pathlib import Path
 
 
 def builder_inited(app):
     """Define certain settings
     """
-    mydir = Path(__file__).parent.child('static').absolute()
-    app.config.html_static_path.append(mydir)
-    app.config.html_logo = mydir.child('logo_web3.png')
-    app.config.html_favicon = mydir.child('favicon.ico')
+    mydir = (Path(__file__).parent / 'static').absolute()
+    app.config.html_static_path.append(str(mydir))
+    app.config.html_logo = str(mydir / 'logo_web3.png')
+    app.config.html_favicon = str(mydir / 'favicon.ico')
 
 
 def setup(app):
-    app.add_css_file('linodocs.css')
+    # app.add_css_file('linodocs.css')
     # app.add_stylesheet('centeredlogo.css')
     app.connect('builder-inited', builder_inited)
