@@ -1,5 +1,5 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2020 Rumma & Ko Ltd
+# Copyright 2009-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """:mod:`lino.utils` (the top-level module) contains a few often-used
@@ -13,6 +13,7 @@ function for general use. It has also many subpackages and submodules.
     choosers
     code
     config
+    cycler
     dates
     demonames
     daemoncommand
@@ -80,22 +81,7 @@ class AttrDict(dict):
     """
     Dictionary-like helper object.
 
-    Usage example:
-
-    >>> from lino.utils import AttrDict
-    >>> a = AttrDict()
-    >>> a.define('foo', 1)
-    >>> a.define('bar', 'baz', 2)
-    >>> a == {"bar": {"baz": 2}, "foo": 1}
-    True
-    >>> print(a.foo)
-    1
-    >>> print(a.bar.baz)
-    2
-    >>> print(a.resolve('bar.baz'))
-    2
-    >>> print(a.bar)
-    {'baz': 2}
+    See usage example in :doc:`/topics/utils`
 
     """
     def __getattr__(self, name):
@@ -138,17 +124,7 @@ def date_offset(ref, days=0, **offset):
     """
     Compute a date using a "reference date" and an offset.
 
-    >>> r = i2d(20140222)
-
-    In 10 days:
-    >>> date_offset(r, 10)
-    datetime.date(2014, 3, 4)
-
-    Four hundred days ago:
-    >>> date_offset(r, -400)
-    datetime.date(2013, 1, 18)
-
-
+    Usage examples in :doc:`/topics/datetime`.
     """
     if days:
         offset.update(days=days)
@@ -160,15 +136,7 @@ def iif(condition, true_value, false_value=None):
     """
     "Inline If" : an ``if`` statement as a function.
 
-    Examples:
-
-    >>> from lino.utils import iif
-    >>> print("Hello, %s world!" % iif(1+1==2, "real", "imaginary"))
-    Hello, real world!
-    >>> iif(True, "true")
-    'true'
-    >>> iif(False, "true")
-
+    Examples in :doc:`/topics/utils`.
     """
     if condition:
         return true_value
@@ -178,15 +146,7 @@ def iif(condition, true_value, false_value=None):
 def last_day_of_month(d):
     """Return the last day of the month of the given date.
 
-    >>> from lino.utils import i2d
-    >>> last_day_of_month(i2d(20160212))
-    datetime.date(2016, 2, 29)
-    >>> last_day_of_month(i2d(20161201))
-    datetime.date(2016, 12, 31)
-    >>> last_day_of_month(i2d(20160123))
-    datetime.date(2016, 1, 31)
-    >>> last_day_of_month(i2d(20161123))
-    datetime.date(2016, 11, 30)
+    Examples in :doc:`/topics/datetime`.
 
     Thanks to `stackoverflow.com
     <https://stackoverflow.com/questions/42950/get-last-day-of-the-month-in-python>`_.
@@ -261,14 +221,7 @@ def join_words(*words):
 
     TODO: move this to etgen.html ?
 
-    >>> print(join_words('This','is','a','test'))
-    This is a test
-
-    >>> print(join_words('This','is','','another','test'))
-    This is another test
-
-    >>> print(join_words(None, None, None, 'Third', 'test'))
-    Third test
+    See examples in :doc:`/topics/utils`.
 
     """
     return ' '.join([str(x) for x in words if x])
@@ -333,7 +286,7 @@ def str2hex(s):
     """
     Convert a string to its hexadecimal representation.
 
-    See examples in :func:`hex2str`.
+    See examples in :doc:`/topics/formatting`.
 
 
     """
@@ -350,16 +303,7 @@ def hex2str(value):
 
     See also :func:`str2hex`.
 
-    >>> str2hex('-L')
-    '2d4c'
-
-    >>> hex2str('2d4c')
-    '-L'
-
-    >>> hex2str('')
-    ''
-    >>> str2hex('')
-    ''
+    Examples in :doc:`/topics/formatting`.
 
 
     """
@@ -380,88 +324,13 @@ curry = lambda func, *args, **kw:\
 
 class IncompleteDate(object):
 
-    """
-    Naive representation of a potentially incomplete gregorian date.
+    """Naive representation of a potentially incomplete gregorian date.
 
-    For example you can say "Once upon a time in the year 2011":
-
-    >>> print(IncompleteDate(2011, 0, 0).strftime("%d.%m.%Y"))
-    00.00.2011
-
-    Unlike :class:`datetime.date` objects an incomplete date can hold years
-    before 1970.
-
-    >>> print(IncompleteDate(1532, 0, 0))
-    1532-00-00
-
-    On June 1st (but we don't say the year):
-
-    >>> print(IncompleteDate(0, 6, 1))
-    0000-06-01
-
-    On the first day of the month in 1990:
-
-    >>> print(IncompleteDate(1990, 0, 1))
-    1990-00-01
-
-    W.A. Mozart's birth date:
-
-    >>> print(IncompleteDate(1756, 1, 27))
-    1756-01-27
-
-    Christ's birth date:
-
-    >>> print(IncompleteDate(-7, 12, 25))
-    -7-12-25
-    >>> print(IncompleteDate(-7, 12, 25).strftime("%d.%m.%Y"))
-    25.12.-7
-
-    Note that you cannot convert all incomplete dates
-    to real datetime.date objects:
-
-    >>> IncompleteDate(-7, 12, 25).as_date()
-    ... #doctest: +ELLIPSIS
-    Traceback (most recent call last):
-    ...
-    ValueError: year...is out of range
-
-    >>> IncompleteDate(1756, 1, 27).as_date()
-    datetime.date(1756, 1, 27)
-
-    An IncompleteDate is allowed to be complete:
-
-    >>> d = IncompleteDate.parse('2011-11-19')
-    >>> print(d)
-    2011-11-19
-    >>> d.is_complete()
-    True
-    >>> print(repr(d.as_date()))
-    datetime.date(2011, 11, 19)
-
-    >>> d = IncompleteDate.parse('2008-03-24')
-    >>> d.get_age(i2d(20131224))
-    5
-    >>> d.get_age(i2d(20140323))
-    5
-    >>> d.get_age(i2d(20140324))
-    6
-    >>> d.get_age(i2d(20140325))
-    6
-    >>> d.get_age(i2d(20141025))
-    6
-
-    Note that IncompleteDate can store invalid dates:
-
-    >>> d = IncompleteDate(2009, 2, 30)
-    >>> d.get_age(i2d(20160202))
-    6
-
-    >>> IncompleteDate(2009, 2, 32)
-    IncompleteDate('2009-02-32')
-
-    >>> IncompleteDate(2009, 32, 123)
-    IncompleteDate('2009-32-123')
+    Where *incomplete* means that maybe only the year is known and day and month
+    is unknown or similarly otherwise. Such a date may not always be convertible
+    to :class:`datetime.date`.
 
+    Some examples are in :doc:`/topics/datetime`.
     """
 
     def __init__(self, year, month, day):
@@ -473,32 +342,7 @@ class IncompleteDate(object):
         Parse the given string and return an :class:`IncompleteDate`
         object.
 
-        >>> IncompleteDate.parse('2008-03-24')
-        IncompleteDate('2008-03-24')
-
-        Belgian eID cards gave us some special challenges:
-
-        >>> IncompleteDate.parse('01.JUN. 1968')
-        IncompleteDate('1968-06-01')
-
-        >>> IncompleteDate.parse('JUN. 1968')
-        IncompleteDate('1968-06-00')
-
-        >>> IncompleteDate.parse('13 maart 1953')
-        IncompleteDate('1953-03-13')
-
-        >>> IncompleteDate.parse('13 januari 1953')
-        IncompleteDate('1953-01-13')
-
-        Return None when we could not understand the string.
-
-        >>> IncompleteDate.parse('foo bar')
-
-        dateparser unfortunately does not understand that "MAAR" is the
-        abbreviation for dutch "MAART" (which means "March"). So here it returns
-        None:
-
-        >>> IncompleteDate.parse('13 MAAR 1953')
+        Examples in :doc:`/topics/datetime`.
 
         """
 
@@ -598,17 +442,7 @@ def moneyfmt(value, places=2, curr='', sep=',', dp='.',
     | neg:      optional sign for negative numbers: '-', '(', space or blank
     | trailneg: optional trailing minus indicator:  '-', ')', space or blank
 
-    >>> d = Decimal('-1234567.8901')
-    >>> print(moneyfmt(d, curr='$'))
-    -$1,234,567.89
-    >>> print(moneyfmt(d, places=0, sep='.', dp='', neg='', trailneg='-'))
-    1.234.568-
-    >>> print(moneyfmt(d, curr='$', neg='(', trailneg=')'))
-    ($1,234,567.89)
-    >>> print(moneyfmt(Decimal(123456789), sep=' '))
-    123 456 789.00
-    >>> print(moneyfmt(Decimal('-0.02'), neg='<', trailneg='>'))
-    <0.02>
+    See examples in :doc:`/topics/formatting`.
 
     """
     q = Decimal(10) ** -places      # 2 places --> '0.01'
@@ -657,25 +491,9 @@ def workdays(start, end):
     Return the number of workdays (Monday to Friday) between the given
     two dates. Is not aware of holidays.
 
-    Both dates start and end are included. For example if you
-    specify a Monday as start and Monday of the following
-    week as end, then you get 6 (not 5).
-
-    Examples:
-    >>> examples = [
-    ...   (20121130,20121201,1),
-    ...   (20121130,20121224,17),
-    ...   (20121130,20121130,1),
-    ...   (20121201,20121201,0),
-    ...   (20121201,20121202,0),
-    ...   (20121201,20121203,1),
-    ...   (20121130,20121207,6),
-    ... ]
-    >>> for start,end,expected in examples:
-    ...     a = i2d(start)
-    ...     b = i2d(end)
-    ...     if workdays(a,b) != expected:
-    ...        print("Got %d instead of %d for (%s,%s)" % (workdays(a,b),expected,a,b))
+    Both dates start and end are included. For example if you specify a Monday
+    as start and Monday of the following week as end, then you get 6 (not 5).
+    See examples in: :doc:`/topics/datetime`.
 
     """
     #~ for d in range(start,end,ONE_DAY):
@@ -692,12 +510,10 @@ def workdays(start, end):
 
 def camelize(s):
     """
-    >>> camelize("ABC DEF")
-    'Abc Def'
-    >>> camelize("ABC def")
-    'Abc def'
-    >>> camelize("eID")
-    'eID'
+    Convert the given string into a `camel-case
+    <https://en.wikipedia.org/wiki/Camel_case>`_ string.
+
+    Usage examples in :doc:`/topics/formatting`.
 
     """
     def f(k):
@@ -716,13 +532,7 @@ def uncamel(s):
     Thanks to `nickl <https://stackoverflow.com/users/1522117/nickl>`_
     in `Stackoverflow  <https://stackoverflow.com/questions/1175208>`_
 
-    >>> from lino.utils import uncamel
-    >>> uncamel('EventsByClient')
-    'events_by_client'
-    >>> uncamel('Events')
-    'events'
-    >>> uncamel('HTTPResponseCodeXYZ')
-    'http_response_code_xyz'
+    Usage examples in :doc:`/topics/formatting`.
 
     """
     return UNCAMEL_RE.sub(r'_\1', s).lower()
@@ -752,38 +562,14 @@ def puts(s):
 class SumCollector(object):
     """A dictionary of sums to be collected using an arbitrary key.
 
-    Usage examples:
-
-    >>> sc = SumCollector()
-    >>> sc.collect("a", 12)
-    >>> sc.collect("b", 23)
-    >>> sc.collect("a", 34)
-    >>> sc
-    OrderedDict([('a', 46), ('b', 23)])
-
-    >>> sc = SumCollector()
-    >>> sc.collect("a", 12)
-    >>> sc.collect("a", None)
-    >>> sc.collect("a", 5)
-    >>> sc.a
-    17
-
-    >>> sc = SumCollector()
-    >>> from lino.utils.quantities import Duration
-    >>> sc.collect("a", Duration("0:30"))
-    >>> sc.collect("a", Duration("0:35"))
-    >>> sc.collect("b", Duration("0:00"))
-    >>> sc.a
-    Duration('1:05')
-    >>> sc.b
-    Duration('0:00')
-
     This is also included in the default context used by the Jinja
     renderer (:mod:`lino.modlib.jinja`) when rendering templates,
     which makes it a more complete solution for a problem asked also
     elsewhere, e.g. on `Stackoverflow
     <https://stackoverflow.com/questions/7537439/how-to-increment-a-variable-on-a-for-loop-in-jinja-template>`__.
 
+    See examples in :doc:`/topics/utils`.
+
     """
     def __init__(self):
         self._sums = OrderedDict()
@@ -830,6 +616,13 @@ def get_client_ip_address(request):
 
 
 class DelayedValue:
+    """
+
+    Creates an url for the related value and passes it to the frontend for the
+    value to be fetched later by the frontend.
+
+    """
+
     def __init__(self, ar, fieldname, obj):
         if fieldname is None:
             raise Exception("20210617 {}".format(field))
