@@ -309,9 +309,9 @@ class Chooser(FieldChooser):
             self.model.__name__, self.field.name,
             self.context_params)
 
-    def create_choice(self, obj, text):
+    def create_choice(self, obj, text, ar=None):
         m = getattr(obj, "create_%s_choice" % self.field.name)
-        return m(text)
+        return m(text, ar)
 
     def get_data_elem(self, name):
         """Calls :meth:`dd.Actor.get_data_elem` or
@@ -366,14 +366,17 @@ class Chooser(FieldChooser):
 
             pk = rqdata.get(constants.URL_PARAM_MASTER_PK, None)
             if pk and master:
-                try:
-                    kw[tbl.master_field.name] = master.objects.get(pk=pk)
-                except ValueError:
-                    raise Exception(
-                        "Invalid primary key %r for %s", pk, master.__name__)
-                except master.DoesNotExist:
-                    raise Exception("There's no %s with primary key %r" %
-                                    (master.__name__, pk))
+                if 'get_master_instance' in tbl.__dict__:
+                    kw[tbl.master_field.name] = tbl.get_master_instance(ar, master, pk)
+                else:
+                    try:
+                        kw[tbl.master_field.name] = master.objects.get(pk=pk)
+                    except ValueError:
+                        raise Exception(
+                            "Invalid primary key %r for %s", pk, master.__name__)
+                    except master.DoesNotExist:
+                        raise Exception("There's no %s with primary key %r" %
+                                        (master.__name__, pk))
 
         for k, v in list(ar.request.GET.items()):
             kw[str(k)] = v
@@ -420,6 +423,8 @@ def uses_simple_values(holder, fld):
         return False
     # if isinstance(fld, models.OneToOneRel):
     #     return False
+    if not hasattr(fld, 'name'):
+        raise Exception("DEBUG", holder, fld, fld.display_mode_main, fld.display_mode_slave)
     if holder is not None and fld.name is not None:
         ch = holder.get_chooser_for_field(fld.name)
         if ch is not None:
