@@ -1,14 +1,11 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2017 Rumma & Ko Ltd
+# Copyright 2012-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 """
 Defines some utilities to inspect the running Python code.
 
 """
-from builtins import str
-from builtins import object
-
 import logging
 logger = logging.getLogger(__name__)
 
@@ -26,9 +23,9 @@ def codefiles(pattern='*'):
     """
     #~ exp = re.compile(pattern, flags)
 
-    for name, mod in sys.modules.items():
+    for name, mod in sys.modules.copy().items():
         #~ if name == 'lino.extjs' and pattern == '*':
-            #~ logger.info("20130801 %r -> %r", name,mod.__file__)
+            # ~ logger.info("20130801 %r -> %r", name,mod.__file__)
         if fnmatch.fnmatch(name, pattern):
         #~ if exp.match(name):
             filename = getattr(mod, "__file__", None)
@@ -123,10 +120,11 @@ class SourceFile(object):
 
 def analyze_rst(*packages):
     """
-    Example:
 
-    >>> from lino.utils.code import analyze_rst
-    >>> print analyze_rst('lino')
+    A function to produce an analytical description of the given packages in RST
+    format.
+
+    Example in :doc:`/topics/utils`.
 
     """
     fields = 'count_code count_doc count_comment count_total'.split()
