@@ -189,6 +189,7 @@ class Analyzer(object):
             #~ ,"first","last"
         ]
         rows = []
+        errors = []
         for model in models_list:
             if True:  # model._meta.managed:
                 i += 1
@@ -211,9 +212,49 @@ class Analyzer(object):
                 #~ else:
                 #~ cells.append('')
                 #~ cells.append('')
-
                 rows.append(cells)
+
+                duped_messages = list()
+                for base in model.__mro__:
+                    if not issubclass(base, (models.Model, dd.Model)) or base in [models.Model, dd.Model] or base.__name__ == model.__name__:
+                        continue
+                    base_name = base.__name__
+                    subbases = set()
+                    trees = {base_name}
+                    def find_subbases(base, subbase):
+                        for _subbase in subbase.__subclasses__():
+                            app_label = _subbase._meta.app_label
+                            if app_label is not None:
+                                plugin = dd.plugins.get(app_label, None)
+                                if plugin is not None:
+                                    em = plugin.extends_models
+                                    if em is not None and _subbase.__name__ in em:
+                                        continue
+                            _item = ""
+                            for item in trees:
+                                if item.endswith(subbase.__name__):
+                                    _item = item
+                                    break
+                            if _subbase.__name__ == model.__name__:
+                                if app_label == model._meta.app_label:
+                                    trees.add(_item + '.' + _subbase.__name__)
+                                    subbases.add(subbase)
+                            else:
+                                trees.add(_item + '.' + _subbase.__name__)
+                                find_subbases(base, _subbase)
+                    find_subbases(base, base)
+                    if len(subbases) > 1 and len(base._meta.concrete_fields):
+                        trees = sorted(list({item for item in trees if item.endswith(model.__name__)}), key=lambda v: len(v))
+                        duped_messages.append((
+                            'Duplicate base:\n\t' + base_name + '\nInheritance trees:\n\t' +
+                            '\n\t'.join(trees)
+                        ))
+                if duped_messages:
+                    errors.append('\nModel:\n\t' + model.__module__ + '.' + model.__name__ + '\n' + ('\n' + '-'*40 + '\n').join(duped_messages))
+
         s += rstgen.table(headers, rows)
+        if errors:
+            s += ('\nFound ' + str(len(errors)) + ' model with duplicate bases\n' + '~'*70 + (('\n' + '~'*70)*2).join(errors))
         return s
 
     def show_foreign_keys(self):
