@@ -1,34 +1,12 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2009-2018 Rumma & Ko Ltd
+# Copyright 2009-2021 Rumma & Ko Ltd
 # License: GNU Affero General Public License v3 (see file COPYING for details)
 
 r"""A framework for generating Javascript from Python.
 
 See also :doc:`/specs/jsgen`.
 
-Example:
-
->>> class TextField(Component):
-...    declare_type = DECLARE_VAR
->>> class Panel(Component):
-...    declare_type = DECLARE_VAR
->>> fld1 = TextField(fieldLabel="Field 1", name='fld1', xtype='textfield')
->>> fld2 = TextField(fieldLabel="Field 2", name='fld2', xtype='textfield')
->>> fld3 = TextField(fieldLabel="Field 3", name='fld3', xtype='textfield')
->>> p1 = Panel(title="Panel",name='p1', xtype='panel', items=[fld2, fld3])
->>> main = Component(title="Main", name='main', xtype='form', items=[fld1, p1])
->>> d = dict(main=main, wc=[1, 2, 3])
-
->>> for ln in declare_vars(d):
-...   print(ln)
-var fld11 = { "fieldLabel": "Field 1", "xtype": "textfield" };
-var fld22 = { "fieldLabel": "Field 2", "xtype": "textfield" };
-var fld33 = { "fieldLabel": "Field 3", "xtype": "textfield" };
-var p14 = { "items": [ fld22, fld33 ], "title": "Panel", "xtype": "panel" };
-
->>> print(py2js(d))
-{ "main": { "items": [ fld11, p14 ], "title": "Main", "xtype": "form" }, "wc": [ 1, 2, 3 ] }
-
+Example in :doc:`/topics/utils`.
 """
 
 import types
