@@ -1,6 +1,6 @@
 # -*- coding: UTF-8 -*-
-# Copyright 2012-2016 Rumma & Ko Ltd
-# License: BSD (see file COPYING for details)
+# Copyright 2012-2021 Rumma & Ko Ltd
+# License: GNU Affero General Public License v3 (see file COPYING for details)
 
 r""" OdsReader uses odfpy to extract data from an .ods document
 (OpenOffice.org spreadsheet).
@@ -17,32 +17,9 @@ database using a :ref:`dpy` fixture, but not limited to this usage.
 
 State : works for me, but very young and probably full of bugs.
 
-Usage example:
-
-The following code reads a file :srcref:`odsreader_sample.ods` 
-and prints a line of text for each row of data.
-
->>> class Sample(OdsReader):
-...     filename = srcpath('odsreader_sample.ods')
-...     headers = ["N°", "Prénom", "Last name", "Country", "City", "Language"]
-...     column_names = 'no first_name last_name country city language'.split()
-...    
->>> for row in Sample().rows():
-...     print( "%(first_name)s %(last_name)s from %(city)s" % row)
-Rudi Rutté from Eupen
-Romain Raffault from Liège
-Rando Roosi from Tallinn
-Rik Rozenbos from Antwerpen
-Robin Rood from London
-
-(Note: these are fictive person names from :mod:`lino.modlib.users.fixtures.demo`).
-
+Usage example in :doc:`/topics/utils`.
 
 """
-from __future__ import print_function, unicode_literals
-from builtins import str
-from builtins import range
-from builtins import object
 import logging
 # ~ logging.basicConfig(level='DEBUG') # uncomment this when debugging
 logger = logging.getLogger(__name__)
@@ -133,12 +110,12 @@ class SimpleOdsReader(object):
 class OdsReader(SimpleOdsReader):
 
     """
-    Like :class:`SimpleOdsReader`, but each row is converted to 
-    an :class:`lino.utils.AttrDict`. This requires you to specifiy, 
-    besides the :attr:`SimpleOdsReader.headers` attrribute, 
-    another list of pure ASCII strings which must be valid Python 
+    Like :class:`SimpleOdsReader`, but each row is converted to
+    an :class:`lino.utils.AttrDict`. This requires you to specifiy,
+    besides the :attr:`SimpleOdsReader.headers` attrribute,
+    another list of pure ASCII strings which must be valid Python
     attribute names.
-    
+
     """
     column_names = None
 
